@@ -29,6 +29,7 @@
 #include "htmlgdkpainter.h"
 #include "htmlprinter.h"
 #include "htmliframe.h"
+#include "htmlengine.h"
 #include "htmlengine-search.h"
 #include "htmlengine-save.h"
 #include "htmlsearch.h"
@@ -140,8 +141,10 @@ set_max_width (HTMLObject *o, HTMLPainter *painter, gint max_width)
 {
 	HTMLEngine *e = GTK_HTML (HTML_IFRAME (o)->html)->engine;
 
-	o->max_width = max_width;
-	html_object_set_max_width (e->clue, e->painter, max_width - (html_engine_get_left_border (e) + html_engine_get_right_border (e)));
+	if (o->max_width != max_width) {
+		o->max_width = max_width;
+		html_object_set_max_width (e->clue, e->painter, max_width - (html_engine_get_left_border (e) + html_engine_get_right_border (e)));
+	}
 }
 
 static void
@@ -306,7 +309,6 @@ html_iframe_real_calc_size (HTMLObject *o, HTMLPainter *painter, GList **changed
 {
 	HTMLIFrame *iframe;
 	HTMLEngine *e;
-	gint width, height;
 	gint old_width, old_ascent, old_descent;
 	
 	old_width = o->width;
@@ -320,21 +322,15 @@ html_iframe_real_calc_size (HTMLObject *o, HTMLPainter *painter, GList **changed
 		return TRUE;
 
 	if ((iframe->width < 0) && (iframe->height < 0)) {
-		e->width = o->max_width;
-		html_engine_calc_size (e, changed_objs);
-
-		height = html_engine_get_doc_height (e);
-		width = html_engine_get_doc_width (e);
-
-		gtk_widget_set_size_request (iframe->scroll, width, height);
-		gtk_widget_queue_resize (iframe->scroll);
-		
+		if (e->clue) {
+			html_engine_calc_size (e, changed_objs);
+			e->width = html_engine_get_doc_width (e);
+			e->height = html_engine_get_doc_height (e);
+		}
 		html_iframe_set_scrolling (iframe, GTK_POLICY_NEVER);
 
-		e->width = width;
-		e->height = height;
-		o->width = width;
-		o->ascent = height;
+		o->width = e->width;
+		o->ascent = e->height;
 		o->descent = 0;
 	} else
 		return (* HTML_OBJECT_CLASS (parent_class)->calc_size) (o, painter, changed_objs);
@@ -620,7 +616,9 @@ html_iframe_init (HTMLIFrame *iframe,
 			handle = gtk_html_begin (new_html);
 			g_signal_emit_by_name (parent_html->engine, "url_requested", src, handle);
 		}
-	}
+	} else
+		gtk_html_load_empty (new_html);
+
 	new_html->engine->clue->parent = HTML_OBJECT (iframe);
 	
 #if 0
